@@ -1,5 +1,7 @@
 import traceback
+
 from functools  import wraps
+from time   import time
 
 def try_traceback(skip_traceback=False):
     def try_except(func):
@@ -14,6 +16,18 @@ def try_traceback(skip_traceback=False):
     return try_except
 
 
+def func_timer(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        fprint('Function timer started')
+        time_start = time()
+        ret_val = func(*args, **kwargs)
+        time_delta = time() - time_start
+        fprint(f'Function {func.__name__}{args} {kwargs} Took {time_delta:.4f} seconds to run')
+        return ret_val
+    return wrapper
+
+
 def fprint(text=None, nl=True, flush=False):
     if not text:
         text = ''
@@ -77,4 +91,8 @@ def choose_from_list(lst, header_text='---Choose 1 value---', header_nl=False, i
             fprint(f'Input not a valid index: {inpt_indx}')
 
         if not choose_until_correct:
-            return
\ No newline at end of file
+            return
+
+
+def join_dir(*args, join_with='\\'):
+    return join_with.join(args)
\ No newline at end of file
